embassy-usb-host

Crates

git

Versions

default

Flavors

EnumerationInfo

Struct EnumerationInfo 

pub struct EnumerationInfo {
    pub device_address: u8,
    pub route: BusRoute,
    pub device_desc: DeviceDescriptor,
}
Information obtained through preliminary enumeration.

Fields

device_address: u8

Assigned device address.

route: BusRoute

How the device’s traffic reaches it on the bus (speed + optional split-transaction / PRE-prefix routing).

device_desc: DeviceDescriptor

Parsed device descriptor.

Implementations

Source

impl EnumerationInfo

pub const fn speed(&self) -> Speed

Negotiated device speed.

pub const fn split(&self) -> Option<SplitInfo>

Split-transaction routing, when this device is behind a hub that requires splits (HS host reaching LS/FS device through a HS hub, or FS host reaching LS device through a FS hub). None for a device reached directly.

Source

impl EnumerationInfo

pub async fn active_config_or_set_default<'a, D: IsIn + IsOut, C: UsbPipe<Control, D>>( &self, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<ConfigurationDescriptor<'a>, HostError>

Retrieves the active device configuration, or sets the default if none is active.

pub async fn get_active_configuration<'a, D: IsIn, C: UsbPipe<Control, D>>( &self, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<Option<ConfigurationDescriptor<'a>>, HostError>

Retrieves the active device configuration, or None if none is active.

pub async fn get_configuration<'a, D: IsIn, C: UsbPipe<Control, D>>( &self, index: u8, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<ConfigurationDescriptor<'a>, HostError>

Retrieve a device configuration by index.