embassy-usb-host

Crates

git

Versions

default

Flavors

EnumerationInfo

Struct EnumerationInfo 

pub struct EnumerationInfo {
    pub device_address: u8,
    pub ls_over_fs: bool,
    pub speed: Speed,
    pub device_desc: DeviceDescriptor,
}
Information obtained through preliminary enumeration.

Fields

device_address: u8

Assigned device address.

ls_over_fs: bool

Low-speed device connected via a full-speed or higher hub.

speed: Speed

Negotiated speed.

device_desc: DeviceDescriptor

Parsed device descriptor.

Implementations

Source

impl EnumerationInfo

pub async fn active_config_or_set_default<'a, D: IsIn + IsOut, C: UsbChannel<Control, D>>( &self, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<ConfigurationDescriptor<'a>, HostError>

Retrieves the active device configuration, or sets the default if none is active.

pub async fn get_active_configuration<'a, D: IsIn, C: UsbChannel<Control, D>>( &self, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<Option<ConfigurationDescriptor<'a>>, HostError>

Retrieves the active device configuration, or None if none is active.

pub async fn get_configuration<'a, D: IsIn, C: UsbChannel<Control, D>>( &self, index: u8, channel: &mut C, cfg_desc_buf: &'a mut [u8], ) -> Result<ConfigurationDescriptor<'a>, HostError>

Retrieve a device configuration by index.